/***************************************************************************
    date                 : Jan 22 2004
    version              : 0.10
    copyright            : (C) 2004 by Holger Danielsson
    email                : holger.danielsson@t-online.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CLEANDIALOG_H
#define CLEANDIALOG_H

#include <kdialogbase.h>
#include <tqstringlist.h>

class TDEListView;

/**
  *@author Holger Danielsson
  */

namespace KileDialog 
{
	class Clean : public KDialogBase
	{
	Q_OBJECT
  
	
	public: 
		Clean(TQWidget *parent, const TQString & filename, const TQStringList &extlist);
		~Clean();
		const TQStringList & getCleanlist();
	
	private:
		TDEListView		*listview;   
		TQStringList	m_extlist;
	};
}

#endif
